{pkgs, ...}: {
  shell = {
    fish.enable = true;
    oh-my-posh.enable = true;
  };

  console.yazi.enable = true;

  stylix.targets.fzf.enable = false;
  services.ssh-agent.enable = true;
  services.pueue.enable = true;

  syncthing.enable = true;

  programs = {
    bat.enable = true;
    btop = {
      enable = true;
      settings.update_ms = 200;
    };
    eza.enable = true;
    fd.enable = true;
    fzf = {
      enable = true;
      defaultOptions = ["--color=16"];
    };
    pay-respects.enable = true;
    nix-index.enable = true;
    nix-index-database.comma.enable = true;
    gitui.enable = true;
    git = {
      enable = true;
      delta.enable = true;
      signing.format = "ssh";
      aliases = {
        cl = "clone";
        co = "checkout";
        pom = "push origin main";
      };
    };
    jujutsu.enable = true;
    ripgrep.enable = true;
  };

  terminal = {
    ghostty.enable = true;
    kitty.enable = true;
  };

  editor = {
    helix.enable = true;
  };

  home.packages = with pkgs; [
    alejandra # nix formatter in rust
    devenv # programming deps in rust
    dua # disk space usage in rust
    fend # calculator in rust
    flatpak # flatpak cli
    jj-fzf # fuzzy finder jujutsu tui
    just # make in rust
    mprocs # process runner in rust
    ouch # archive manager in rust
    overskride # bluetooth gui in rust
    pika-backup # borg gui in rust
    pinentry-qt # pinentry for rbw
    procs # ps in rust
    rbw # bitwarden cli in rust
    silicon # create code pics in rust
    trashy # trash cli in rust
    vial # qmk keyboard configuring app
    virt-manager # libvirt gui
    waycheck # check wayland protocols
  ];

  xdg.desktopEntries = {
    uni = {
      actions."Copy".exec = "fish -c \"~/.local/bin/uni --copy\"";
      categories = ["Utility" "X-Launch" "Network"];
      comment = "Select and open or copy URLs from a list.";
      exec = "fish -c \"~/.local/bin/uni\"";
      icon = "web-browser";
      name = "Uni URL Handler";
      startupNotify = true;
      terminal = false;
      type = "Application";
    };
  };
}
