{pkgs, ...}: {
  shell = {
    fish.enable = true;
    #nushell.enable = true;
    oh-my-posh.enable = true;
  };

  console.yazi.enable = true;

  services.ssh-agent.enable = true;

  programs = {
    bat.enable = true;
    btop = {
      enable = true;
      settings.update_ms = 200;
    };
    eza.enable = true;
    fd.enable = true;
    fzf = {
      enable = true;
      defaultOptions = ["--color=16"];
    };
    pay-respects.enable = true;
    nix-index.enable = true;
    nix-index-database.comma.enable = true;
    gitui.enable = true;
    git = {
      enable = true;
      delta.enable = true;
      signing.format = "ssh";
      aliases = {
        cl = "clone";
        co = "checkout";
        pom = "push origin main";
      };
    };
    jujutsu.enable = true;
    ripgrep.enable = true;
  };

  editor = {
    helix.enable = true;
  };

  home.packages = with pkgs; [
    alejandra # nix formatter in rust
    trashy # trash cli in rust
    devenv # programming deps in rust
    procs # ps in rust
    ouch # archive manager in runt
    dust # du in rust
    fend # calc in rust
    moar # better pager (in go)
    just # make in rust
    rbw # bitwarden cli in rust
    jj-fzf # fuzzy finder jujutsu tui
  ];
  systemd.user.settings.Manager.DefaultEnvironment.PAGER = "moar";
}
